#
# spec file for package switchboard-plug-about
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.settings.system
Name:           switchboard-plug-about
Version:        8.2.0
Release:        1.1
Summary:        Switchboard plug to show system information
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/switchboard-plug-about
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(appstream) >= 1.0.0
BuildRequires:  pkgconfig(fwupd)
BuildRequires:  pkgconfig(glib-2.0) >= 2.73.0
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gudev-1.0)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(packagekit-glib2)
BuildRequires:  pkgconfig(polkit-gobject-1)
BuildRequires:  pkgconfig(switchboard-3)
BuildRequires:  pkgconfig(udisks2)
Requires:       switchboard
Requires:       switcheroo-control

%description
About plug for Switchboard.

This plug displays information about the system.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}
%find_lang %{appid}

%files
%license COPYING
%doc README.md
%dir %{_libdir}/{switchboard-3,switchboard-3/hardware}
%{_libdir}/switchboard-3/hardware/libsystem.so
%{_datadir}/metainfo/%{appid}.metainfo.xml.in

%files lang -f %{appid}.lang

%changelog
* Fri Feb 14 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 8.2.0:
  * Prevent software_grid change vertical position, when content changes
  * SystemUpdate: Get last refresh time directly from Settings Daemon
  * HardwareView: Fix fallback when hostname1 returns null values
  * Add Update Progress Indicator
  * Show update size in OperatingSystemView
- remove patch revert-progress-bar.patch, as upstream fixed the issue
* Fri Dec 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.1.0:
  * Add hexpand
  * Meson: add log domain
  * build: Fix build with fwupd 2.0.0
  * Fix Scroll Padding
  * Plug: use Adw.ToolbarView
  * Show sponsor goal progress bar
  * Updated translations
- add patch revert-progress-bar.patch
* Tue Nov 12 2024 Richard Rahl <rrahl0@opensuse.org>
- Require switchboard at runtime
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Manage Operating System updates, including automatic updates
  * Manage additional drivers
  * Improve operating system image for other Linux distributions
  * Updated translations
- update to 6.2.0:
  * Handle Ryzen CPU and AMD GPU vendor string and break on first regex match
  * Better memory and storage info
  * Reboot to Firmware Setup
  * Add meson option for overlaying logo on wallpaper
  * Use /usr/lib/upstream-os-release instead of /etc/upstream-release/lsb-release
- update to 6.1.0:
  * Added support for dark style manufacturer logos
  * Added support for offline firmware updates
  * Updated translations
- update to 6.0.1:
  * Use formatted device name when available
  * Display more information for certain GPUs, including Intel® Xe Graphics
  * Updated translations
- update to 6.0.0:
  * Rename from About to System
  * Split Hardware and Operating System info into their own tabs
  * Redesign the Operating System tab with clearer links and buttons
  * Add a Firmware view to manage device firmware updates
  * Provide information for ARM CPUs
  * Provide information for more types of Graphics
  * Fix an issue where the view was destroyed early when navigating away
  * Fix system memory calculation
  * Ellipsize long hardware names
  * Performance improvements
  * Updated translations
- update to 2.6.3:
  * update translations
- update to 2.6.2:
  * update translations
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.6.1:
  * Add Release to Actions
  * Add Gettext Updates to Actions
  * Split deb packaging into its own branch
  * Delete CODE_OF_CONDUCT.md
  * run installation in CI (#107)
  * Add Lint to CI (#105)
  * Fix linting errors
  * Use GitHub CI (#104)
* Mon Nov  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.6.0:
  * New upstream release.
- Restore information about architecture type (plug-about-arch.patch)
* Tue Mar 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.5.2:
  * New upstream release.
- Update switchboard-plug-about-info.patch
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Wed Oct 17 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.5.1:
  * New upstream release.
* Mon Jun 11 2018 avvissu@yandex.by
- Update to 0.2.5:
  * New upstream release.
* Sat Jun  9 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Update switchboard-plug-about-info.patch
- Spec file cleanup
* Thu Oct  5 2017 avvissu@yandex.by
- Update to 0.2.4:
  * Update call to AppCenter updates (#40)
  * Drop custom utsname.vapi and use vala's posix binding (#39)
  * Plug.vala: ellipsize long distro names (#37)
- Change the sourceurl to git
* Sat Jul  1 2017 avvissu@yandex.by
- Update to 0.2.3.1:
  * Specify an icon pixel size for the OS Logo Icon (#32)
  * Create CODE_OF_CONDUCT.md (#30)
* Fri Jun 16 2017 avvissu@yandex.by
- Update to 0.2.3:
  * Using null instead of a string with null (#29)
  * Implement Preferences URL Specification (#28)
- Update patch: 0.2.2_about.patch > info.patch
* Sat Apr 22 2017 avvissu@yandex.by
- Update to 0.2.2:
  * Add Travis CI (#19)
  * Put actions in a buttonbox (#18)
  * Show kernel version (#17)
  * Update translations URL to Weblate (#16)
  * Show GTK version (#13)
  * Create README.md (#12)
  * Rework os-release(5) parsing to be less brittle.
  * Since /etc/os-release is effectively a set of key-value
    pairs, we'll just read the whole thing and import it into a
    HashMap.
  * This allows us to reference arbitrary entries from the file
    and set variables with that data accordingly.
  * Launchpad automatic translations update.
  * Rewrite settings restore dialog as its own widget
  * Updated translation template
  * Fix the plug not building on launchpad
  * Do not Spawn commands when a library is available
  * Use more modern interface
- Update patch: 0.2.1.1_about.patch > 0.2.2_about.patch
* Wed Sep 21 2016 avvissu@yandex.by
- Update to 0.2.1.1:
  * Retrieve metadata from /etc/os-release when possible instead
    of /etc/lsb-release
  * Launchpad automatic translations update.
- Update patch:
  * switchboard-plug-about-0.2.1_about.patch -> 0.2.1.1_about.patch
- Spec file cleanup
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.2.1
- Update switchboard-plug-about-0.2.1_about.patch
  - ------------------------------------------------------------------
* Mon Aug 22 2016 avvissu@yandex.by
- Provide accurate information:
  * add switchboard-plug-about-0.2.1_about.patch
- Spec file cleanup
* Sat Feb 27 2016 mailaender@opensuse.org
- update to version 0.2.0.1
* Tue Sep  8 2015 and.november@opensuse.org
- initial package (version 0.2.0) for build.opensuse.org
